@@ -149,17 +149,6 @@
 #define REG_E1EBCR1		0x56
 #define REG_E1EBCR2		0x57
 
-#define REG_E1RRTS7         0x62
-#define BIT_E1RRTS7_CSC5    0x80
-#define BIT_E1RRTS7_CSC4    0x40
-#define BIT_E1RRTS7_CSC3    0x20
-#define BIT_E1RRTS7_CSC2    0x10
-#define BIT_E1RRTS7_CSC1    0x80
-#define BIT_E1RRTS7_CSC0    0x08
-#define BIT_E1RRTS7_CRC4SA  0x04
-#define BIT_E1RRTS7_CASSA   0x02
-#define BIT_E1RRTS7_FASA    0x01
-
 #define REG_T1RBOC		0x63
 
 #define REG_E1RNAF		0x65
@@ -593,11 +582,9 @@
 #define REG_T1TBOC		0x163
 
 #define REG_E1TAF		0x164
-#define BIT_E1TAF_SI	0x80
 
 #define REG_E1TNAF		0x165
-#define BIT_E1TNAF_A	0x20
-#define BIT_E1TNAF_SI	0x80
+#define BIT_E1TNAF_A		0x20
 
 #define REG_E1TSa4		0x169
 #define REG_E1TSa5		0x16A
@@ -634,7 +621,6 @@
 #define BIT_TCR2_T1_TSLC96	0x40
 #define BIT_TCR2_T1_TD4RM	0x04
 #define BIT_TCR2_E1_AEBE	0x80		/* EBIT */
-#define BIT_TCR2_E1_ARA 	0x20
 
 #define REG_TCR3		0x183
 #define BIT_TCR3_ODF		0x80
