@@ -293,7 +293,7 @@ static int update (wan_device_t* wandev)
 	if(dev == NULL)
 		return -ENODEV;
 
-	if((priv_area=dev->priv) == NULL)
+	if((priv_area=wan_netif_priv(dev)) == NULL)
 		return -ENODEV;
 
 
@@ -410,7 +410,7 @@ static int new_if (wan_device_t* wandev, struct net_device* dev, wanif_conf_t* c
 	 * finished successfully.  DO NOT place any code below that
 	 * can return an error */
 	dev->init = &if_init;
-	dev->priv = priv_area;
+	wan_netif_set_priv(dev, priv_area);
 
 	/* Increment the number of network interfaces 
 	 * configured on this card.  
@@ -441,7 +441,7 @@ static int new_if (wan_device_t* wandev, struct net_device* dev, wanif_conf_t* c
  */
 static int del_if (wan_device_t* wandev, struct net_device* dev)
 {
-	private_area_t* 	priv_area = dev->priv;
+	private_area_t* 	priv_area = wan_netif_priv(dev);
 	sdla_t*			card = priv_area->card;
 
 	/* Decrement the number of network interfaces 
@@ -479,7 +479,7 @@ static int del_if (wan_device_t* wandev, struct net_device* dev)
  */
 static int if_init (struct net_device* dev)
 {
-	private_area_t* priv_area = dev->priv;
+	private_area_t* priv_area = wan_netif_priv(dev);
 	sdla_t* card = priv_area->card;
 	wan_device_t* wandev = &card->wandev;
 
@@ -535,7 +535,7 @@ static int if_init (struct net_device* dev)
  */
 static int if_open (struct net_device* dev)
 {
-	private_area_t* priv_area = dev->priv;
+	private_area_t* priv_area = wan_netif_priv(dev);
 	sdla_t* card = priv_area->card;
 	struct timeval tv;
 	int err = 0;
@@ -585,7 +585,7 @@ static int if_open (struct net_device* dev)
 
 static int if_close (struct net_device* dev)
 {
-	private_area_t* priv_area = dev->priv;
+	private_area_t* priv_area = wan_netif_priv(dev);
 	sdla_t* card = priv_area->card;
 
 	stop_net_queue(dev);
@@ -663,7 +663,7 @@ static void disable_comm (sdla_t *card)
  */
 static int if_send (struct sk_buff* skb, struct net_device* dev)
 {
-	private_area_t *chan = dev->priv;
+	private_area_t *chan = wan_netif_priv(dev);
 	sdla_t *card = chan->card;
 
 	if (skb){
@@ -689,7 +689,7 @@ static struct net_device_stats* if_stats (struct net_device* dev)
 {
 	private_area_t* priv_area;
 
-	if ((priv_area=dev->priv) == NULL)
+	if ((priv_area=wan_netif_priv(dev)) == NULL)
 		return NULL;
 
 	return &priv_area->if_stats;
@@ -719,7 +719,7 @@ static struct net_device_stats* if_stats (struct net_device* dev)
  */
 static int if_do_ioctl(struct net_device *dev, struct ifreq *ifr, int cmd)
 {
-	private_area_t* chan= (private_area_t*)dev->priv;
+	private_area_t* chan= (private_area_t*)wan_netif_priv(dev);
 	//unsigned long smp_flags;
 	wan_mbox_t *mb,*usr_mb;
 	sdla_t *card;
